==> App-lcpan-0.22.tar.gz: App-lcpan-0.22/lib/App/lcpan/Cmd/authorrdeps.pm <==
package App::lcpan::Cmd::authorrdeps;

our $DATE = '2015-04-15'; # DATE
our $VERSION = '0.22'; # VERSION

use 5.010;
use strict;
use warnings;

require App::lcpan;

our %SPEC;

$SPEC{':package'} = {
    v => 1.1,
    summary => "'authorrdeps' command",
};

$SPEC{'handle_cmd'} = {
    v => 1.1,
    summary => "Find distributions that use one of author's modules",
    args => {
        %App::lcpan::common_args,
        %App::lcpan::author_args,
        #detail => {
        #    schema => 'bool',
        #},
        user_author => {
            schema => ['array*', of=>'str*'],
        },
        user_author_isnt => {
            schema => ['array*', of=>'str*'],
        },
    },
};
sub handle_cmd {
    my %args = @_;

    my $author = $args{author};

    my $res = App::lcpan::modules(%args, author=>$author);
    return $res if $res->[0] != 200;

    my $mods = $res->[2];
    my %rdeps_args = %args;
    $rdeps_args{modules} = $mods;
    delete $rdeps_args{author};
    delete $rdeps_args{author_isnt};
    $rdeps_args{author} = $args{user_author};
    $rdeps_args{author_isnt} = $args{user_author_isnt};
    $res = App::lcpan::rdeps(%rdeps_args);
    return $res if $res->[0] != 200;

    $res;
}

1;
# ABSTRACT: 'authorrdeps' command

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Cmd::authorrdeps - 'authorrdeps' command

=head1 VERSION

This document describes version 0.22 of App::lcpan::Cmd::authorrdeps (from Perl distribution App-lcpan), released on 2015-04-15.

=head1 FUNCTIONS


=head2 handle_cmd(%args) -> [status, msg, result, meta]

Find distributions that use one of author's modules.

Arguments ('*' denotes required arguments):

=over 4

=item * B<author>* => I<str>

=item * B<cpan> => I<str>

Location of your local CPAN mirror, e.g. /path/to/cpan.

Defaults to C<~/cpan>.

=item * B<index_name> => I<str> (default: "index.db")

Filename of index.

=item * B<user_author> => I<array[str]>

=item * B<user_author_isnt> => I<array[str]>

=back

Returns an enveloped result (an array).

First element (status) is an integer containing HTTP status code
(200 means OK, 4xx caller error, 5xx function error). Second element
(msg) is a string containing error message, or 'OK' if status is
200. Third element (result) is optional, the actual result. Fourth
element (meta) is called result metadata and is optional, a hash
that contains extra information.

Return value:  (any)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> App-lcpan-0.23.tar.gz: App-lcpan-0.23/lib/App/lcpan/Cmd/authorrdeps.pm <==
package App::lcpan::Cmd::authorrdeps;

our $DATE = '2015-04-16'; # DATE
our $VERSION = '0.23'; # VERSION

use 5.010;
use strict;
use warnings;

require App::lcpan;

our %SPEC;

$SPEC{'handle_cmd'} = {
    v => 1.1,
    summary => "Find distributions that use one of author's modules",
    args => {
        %App::lcpan::common_args,
        %App::lcpan::author_args,
        #detail => {
        #    schema => 'bool',
        #},
        user_author => {
            schema => ['array*', of=>'str*'],
        },
        user_author_isnt => {
            schema => ['array*', of=>'str*'],
        },
    },
};
sub handle_cmd {
    my %args = @_;

    my $author = $args{author};

    my $res = App::lcpan::modules(%args, author=>$author);
    return $res if $res->[0] != 200;

    my $mods = $res->[2];
    my %rdeps_args = %args;
    $rdeps_args{modules} = $mods;
    delete $rdeps_args{author};
    delete $rdeps_args{author_isnt};
    $rdeps_args{author} = $args{user_author};
    $rdeps_args{author_isnt} = $args{user_author_isnt};
    $res = App::lcpan::rdeps(%rdeps_args);
    return $res if $res->[0] != 200;

    $res;
}

1;
# ABSTRACT: Find distributions that use one of author's modules

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Cmd::authorrdeps - Find distributions that use one of author's modules

=head1 VERSION

This document describes version 0.23 of App::lcpan::Cmd::authorrdeps (from Perl distribution App-lcpan), released on 2015-04-16.

=head1 FUNCTIONS


=head2 handle_cmd(%args) -> [status, msg, result, meta]

Find distributions that use one of author's modules.

Arguments ('*' denotes required arguments):

=over 4

=item * B<author>* => I<str>

=item * B<cpan> => I<str>

Location of your local CPAN mirror, e.g. /path/to/cpan.

Defaults to C<~/cpan>.

=item * B<index_name> => I<str> (default: "index.db")

Filename of index.

=item * B<user_author> => I<array[str]>

=item * B<user_author_isnt> => I<array[str]>

=back

Returns an enveloped result (an array).

First element (status) is an integer containing HTTP status code
(200 means OK, 4xx caller error, 5xx function error). Second element
(msg) is a string containing error message, or 'OK' if status is
200. Third element (result) is optional, the actual result. Fourth
element (meta) is called result metadata and is optional, a hash
that contains extra information.

Return value:  (any)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
